#
# Configuration file for using the XML library in GNOME applications
#
prefix="/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol"
exec_prefix="${prefix}"
libdir="${exec_prefix}/lib"
includedir="${prefix}/include"

XMLSEC_LIBDIR="${exec_prefix}/lib"
XMLSEC_INCLUDEDIR=" -D__XMLSEC_FUNCTION__=__func__ -DXMLSEC_NO_SIZE_T -DXMLSEC_NO_GOST=1 -DXMLSEC_NO_GOST2012=1 -DXMLSEC_DL_LIBLTDL=1 -I${prefix}/include/xmlsec1   -I/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/include/libxml2 -I/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/include -I/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/include -I/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/include/libxml2    -I/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/include -I/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/include/openssl -DXMLSEC_CRYPTO_OPENSSL=1"
XMLSEC_LIBS="-L${exec_prefix}/lib -lxmlsec1-openssl -lxmlsec1 -lltdl  -lxml2 -L/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/lib -lxslt -lpthread -licui18n -licuuc -licudata -lm -ldl -lxml2    -Wl,-rpath-link -Wl,/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/lib -L/root/worker/containers/00000po7llm/tmp/build/80754af9/libxmlsec1_1613394170741/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/lib -lcrypto -ldl"
MODULE_VERSION="xmlsec-1.2.29-openssl"

